@@ -1,3 +1,8 @@
+# SPDX-FileCopyrightText: 2018 Arduino SA
+# SPDX-FileCopyrightText: 2019 Brent Rubell for Adafruit Industries
+#
+# SPDX-License-Identifier: MIT
+
 # Copyright (c) 2018 Arduino SA. All rights reserved.
 #
 # This library is free software; you can redistribute it and/or
@@ -13,28 +18,7 @@
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-#
-# The MIT License (MIT)
-#
-# Copyright (c) 2019 Brent Rubell for Adafruit Industries
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+
 """
 `adafruit_atecc`
 ================================================================================
@@ -129,48 +113,28 @@ class ATECC:
         """
         self._debug = debug
         self._i2cbuf = bytearray(12)
-        self._i2c_bus = i2c_bus
-        self._i2c_device = None
-        self.wakeup()
-        if not self._i2c_device:
-            self._i2c_device = I2CDevice(self._i2c_bus, address)
-        self.idle()
+        # don't probe, the device will NACK until woken up
+        self._wake_device = I2CDevice(i2c_bus, 0x00, probe=False)
+        self._i2c_device = I2CDevice(i2c_bus, address, probe=False)
         if (self.version() >> 8) not in (_ATECC_508_VER, _ATECC_608_VER):
             raise RuntimeError(
                 "Failed to find 608 or 508 chip. Please check your wiring."
             )
 
     def wakeup(self):
-        """Wakes up THE ATECC608A from sleep or idle modes.
-        Returns True if device woke up from sleep/idle mode.
-        """
-        while not self._i2c_bus.try_lock():
+        """Wakes up THE ATECC608A from sleep or idle modes."""
+        # This is a hack to generate the ATECC Wake condition, which is SDA
+        # held low for t > 60us (twlo). For an I2C clock freq of 100kHz, 8
+        # clock cycles will be 80us. This signal is generated by trying to
+        # address something at 0x00. It will fail, but the pattern should
+        # wake up the ATECC.
+        # pylint: disable=bare-except
+        try:
+            with self._wake_device as i2c:
+                i2c.write(bytes([0x00]))
+        except:
             pass
-        # check if it exists, first
-        if 0x60 in self._i2c_bus.scan():
-            self._i2c_bus.unlock()
-            return
-        zero_bits = bytearray(2)
-        try:
-            self._i2c_bus.writeto(0x0, zero_bits)
-        except OSError:
-            pass  # this may fail, that's ok - its just to wake up the chip!
-        time.sleep(_TWLO_TIME)
-        data = self._i2c_bus.scan()  # check for an i2c device
-
-        try:
-            if data[0] != 96:
-                raise TypeError("ATECCx08 not found - please check your wiring!")
-        except IndexError:
-            raise IndexError("ATECCx08 not found - please check your wiring!")
-        self._i2c_bus.unlock()
-        if not self._i2c_device:
-            self._i2c_device = I2CDevice(self._i2c_bus, _REG_ATECC_DEVICE_ADDR)
-        # check if we are ready to read from
-        r = bytearray(1)
-        self._get_response(r)
-        if r[0] != 0x11:
-            raise RuntimeError("Failed to wakeup")
+        time.sleep(0.001)
 
     def idle(self):
         """Puts the chip into idle mode
